%
% [feature_labels] = extract_labels(params, numframes)
%
% input:
%    params - EEG general parameters
% output:
%    feature_labels - {F} strings describing each feature dimension
%

function [feature_labels] = extract_labels(params, numframes)
    
    feature_labels = {};
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Parameters used
    wintype        = params.feature.wintype;
    samplefreq     = params.fs;

    fft_enable    = params.feature.fft.enable;
    logfft_enable = params.feature.logfft.enable;

    rpde_enable  = params.feature.rpde.enable;
    rpde_m       = params.feature.rpde.m;
    rpde_tau     = params.feature.rpde.tau;
    rpde_epsilon = params.feature.rpde.epsilon;

    mfcc_enable    = params.feature.mfcc.enable;
    mfcc_dimension = params.feature.mfcc.dimension;
    mfcc_pivot     = params.feature.mfcc.pivot;

    lpc_enable    = params.feature.lpc.enable;
    %  lpc_dimension = params.feature.lpc.dimension;
    lpc_order     = params.feature.lpc.order;

    wavelet_enable = params.feature.wavelet.enable;
    wavelet_levels = params.feature.wavelet.levels;
    wavelet_window = params.feature.wavelet.window;

    mean_enable        = params.feature.mean.enable;
    abs_mean_enable    = params.feature.abs_mean.enable;
    max_enable         = params.feature.max.enable;
    abs_max_enable     = params.feature.abs_max.enable;
    min_enable         = params.feature.min.enable;
    abs_min_enable     = params.feature.abs_min.enable;
    max_min_sum_enable = params.feature.max_min_sum.enable;
    max_min_dif_enable = params.feature.max_min_dif.enable;

    n400_energy_windows = params.feature.n400_energy_windows;

    ehf_enable                  = params.feature.ehf.enable;
    curve_length_enable         = params.feature.curve_length.enable;
    energy_enable               = params.feature.energy.enable;
    nonlinear_energy_enable     = params.feature.nonlinear_energy.enable;
    avg_nonlinear_energy_enable = params.feature.avg_nonlinear_energy.enable;
    spectral_entropy_enable     = params.feature.spectral_entropy.enable;
    sixth_power_enable          = params.feature.sixth_power.enable;
    integral_enable             = params.feature.integral.enable;

    std_enable    = params.feature.std.enable;
    var_enable    = params.feature.var.enable;
    skew_enable   = params.feature.skew.enable;
    kurt_enable   = params.feature.kurt.enable;
    sum_enable    = params.feature.sum.enable;
    median_enable = params.feature.median.enable;

    vel_enable   = params.feature.vel.enable;
    accel_enable = params.feature.accel.enable;
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Create labels 
    
    % Add all FFT labels
    if fft_enable
        for d=1:size(feature_fft,2)
          for w=1:numframes
            feature_labels{end+1} = ['FFT:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_fft,2)
            for w=1:numframes
              feature_labels{end+1} = ['dFFT:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_fft,2)
            for w=1:numframes
              feature_labels{end+1} = ['ddFFT:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add all log FFT labels
    if logfft_enable
        for d=1:size(feature_logfft,2)
          for w=1:numframes
            feature_labels{end+1} = ['logFFT:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_logfft,2)
            for w=1:numframes
              feature_labels{end+1} = ['dlogFFT:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_logfft,2)
            for w=1:numframes
              feature_labels{end+1} = ['ddlogFFT:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add all RPDE labels
    if rpde_enable
        for d=1:size(feature_rpde,2)
          for w=1:numframes
            feature_labels{end+1} = ['RPDE:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_rpde,2)
            for w=1:numframes
              feature_labels{end+1} = ['dRPDE:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_rpde,2)
            for w=1:numframes
              feature_labels{end+1} = ['ddRPDE:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add all MFCC labels
    if mfcc_enable
        for d=1:size(feature_mfcc,2)
          for w=1:size(feature_mfcc,1)
            feature_labels{end+1} = ['MFCC:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_mfcc,2)
            for w=1:size(feature_mfcc,1)
              feature_labels{end+1} = ['dMFCC:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_mfcc,2)
            for w=1:size(feature_mfcc,1)
              feature_labels{end+1} = ['ddMFCC:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add all LPC labels
    if lpc_enable
        for d=1:size(feature_lpc,2)
          for w=1:size(feature_lpc,1)
            feature_labels{end+1} = ['LPC:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_lpc,2)
            for w=1:size(feature_lpc,1)
              feature_labels{end+1} = ['dLPC:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_lpc,2)
            for w=1:size(feature_lpc,1)
              feature_labels{end+1} = ['ddLPC:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add all wavelet labels
    if wavelet_enable
        for d=1:size(feature_wavelet,2)
          for w=1:numframes
            feature_labels{end+1} = ['Wavelet:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:size(feature_wavelet,2)
            for w=1:numframes
              feature_labels{end+1} = ['dWavelet:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:size(feature_wavelet,2)
            for w=1:numframes
              feature_labels{end+1} = ['ddWavelet:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add mean window value label
    if mean_enable
        for w=1:numframes
          feature_labels{end+1} = ['Mean:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dMean:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddMean:W', int2str(w)];
          end
        end
    end

    % Add absolute mean window value label
    if abs_mean_enable
        for w=1:numframes
          feature_labels{end+1} = ['Absmean:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dAbsmean:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddAbsmean:W', int2str(w)];
          end
        end
    end

    % Add maximum window value label
    if max_enable
        for w=1:numframes
          feature_labels{end+1} = ['Max:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dMax:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddMax:W', int2str(w)];
          end
        end
    end

    % Add absolute maximum window value label
    if abs_max_enable
        for w=1:numframes
          feature_labels{end+1} = ['Absmax:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dAbsmax:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddAbsmax:W', int2str(w)];
          end
        end
    end

    % Add minimum window value label
    if min_enable
        for w=1:numframes
          feature_labels{end+1} = ['Min:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dMin:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddMin:W', int2str(w)];
          end
        end
    end

    if abs_min_enable
        for w=1:numframes
          feature_labels{end+1} = ['Absmin:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dAbsmin:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddAbsmin:W', int2str(w)];
          end
        end
    end

    % Add minimum maximum sum window value label
    if max_min_sum_enable
        for w=1:numframes
          feature_labels{end+1} = ['Min+Max:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dMin+Max:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddMin+Max:W', int2str(w)];
          end
        end
    end

    % Add maximum-minimum difference window value label
    if max_min_dif_enable
        for w=1:numframes
          feature_labels{end+1} = ['Max-Min:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dMax-Min:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddMax-Min:W', int2str(w)];
          end
        end
    end

    % Add enhancement factor window value label
    if ehf_enable
        for w=1:numframes
          feature_labels{end+1} = ['EHF:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dEHF:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddEHF:W', int2str(w)];
          end
        end
    end

    % Add curve length window label
    if curve_length_enable
        for w=1:numframes
          feature_labels{end+1} = ['CurveLength:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dCurveLength:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddCurveLength:W', int2str(w)];
          end
        end
    end

    % Add energy window label
    if energy_enable
        for w=1:numframes
          feature_labels{end+1} = ['Energy:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dEnergy:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddEnergy:W', int2str(w)];
          end
        end
    end

    % Add non-linear energy labels
    if nonlinear_energy_enable
        for d=1:framesize
          for w=1:numframes
            feature_labels{end+1} = ['NLE:W', int2str(w), ',D', int2str(d)];
          end
        end

        if vel_enable
          for d=1:framesize
            for w=1:numframes
              feature_labels{end+1} = ['dNLE:W', int2str(w), ',D', int2str(d)];
            end
          end
        end

        if accel_enable
          for d=1:framesize
            for w=1:numframes
              feature_labels{end+1} = ['ddNLE:W', int2str(w), ',D', int2str(d)];
            end
          end
        end
    end

    % Add average non-linear energy window value label
    if avg_nonlinear_energy_enable
        for w=1:numframes
          feature_labels{end+1} = ['AvgNLE:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dAvgNLE:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddAvgNLE:W', int2str(w)];
          end
        end
    end

    % Add spectral entropy window value label
    if spectral_entropy_enable
        for w=1:numframes
          feature_labels{end+1} = ['SE:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dSE:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddSE:W', int2str(w)];
          end
        end
    end

    % Add sixth power window value label
    if sixth_power_enable
        for w=1:numframes
          feature_labels{end+1} = ['SP:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dSP:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddSP:W', int2str(w)];
          end
        end
    end

    % Add integral window value label
    if integral_enable
        for w=1:numframes
          feature_labels{end+1} = ['Integral:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dIntegral:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddIntegral:W', int2str(w)];
          end
        end
    end

    % Add standard deviation window value label
    if std_enable
        for w=1:numframes
          feature_labels{end+1} = ['STD:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dSTD:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddSTD:W', int2str(w)];
          end
        end
    end

    % Add variance window value label
    if var_enable
        for w=1:numframes
          feature_labels{end+1} = ['VAR:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dVAR:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddVAR:W', int2str(w)];
          end
        end
    end

    % Add skewness window value label
    if skew_enable
        for w=1:numframes
          feature_labels{end+1} = ['SKEW:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dSKEW:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddSKEW:W', int2str(w)];
          end
        end
    end

    % Add kurtosis window value label
    if kurt_enable
        for w=1:numframes
          feature_labels{end+1} = ['KURT:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dKURT:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddKURT:W', int2str(w)];
          end
        end
    end

    % Add sum window value label
    if sum_enable
        for w=1:numframes
          feature_labels{end+1} = ['Sum:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dSum:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddSum:W', int2str(w)];
          end
        end
    end

    % Add median window value label
    if median_enable
        for w=1:numframes
          feature_labels{end+1} = ['Energy:W', int2str(w)];
        end

        if vel_enable
          for w=1:numframes
            feature_labels{end+1} = ['dEnergy:W', int2str(w)];
          end
        end

        if accel_enable
          for w=1:numframes
            feature_labels{end+1} = ['ddEnergy:W', int2str(w)];
          end
        end
    end
end